@@ -804,11 +804,12 @@ struct engine_ops _gpgme_engine_ops_g13 =
     NULL,               /* keylist_ext */
     NULL,               /* keylist_data */
     NULL,               /* keysign */
+    NULL,               /* revsig */
     NULL,               /* tofu_policy */
     NULL,               /* sign */
-    NULL,		/* trustlist */
     NULL,               /* verify */
     NULL,               /* getauditlog */
+    NULL,               /* setexpire */
     g13_transact,
     NULL,		/* conf_load */
     NULL,		/* conf_save */
